@@ -29,7 +29,7 @@ def main():
 
     items = train_items + eval_items
 
-    texts = "".join(item[0] for item in items)
+    texts = "".join(item["text"] for item in items)
     chars = set(texts)
     lower_chars = filter(lambda c: c.islower(), chars)
     chars_force_lower = [c.lower() for c in chars]
